aboutsummaryrefslogtreecommitdiff
path: root/engines/titanic/room_flags.h
diff options
context:
space:
mode:
authorPaul Gilbert2016-12-25 23:54:00 -0500
committerPaul Gilbert2016-12-25 23:54:00 -0500
commit81cb0f11dbad5e1744807a926f245c4b2e8307be (patch)
treed88864528ce5aeb25ebac1450594a988377f9b4e /engines/titanic/room_flags.h
parent9755109fddf1da1da1e3322823aa212447f85d14 (diff)
downloadscummvm-rg350-81cb0f11dbad5e1744807a926f245c4b2e8307be.tar.gz
scummvm-rg350-81cb0f11dbad5e1744807a926f245c4b2e8307be.tar.bz2
scummvm-rg350-81cb0f11dbad5e1744807a926f245c4b2e8307be.zip
TITANIC: Cleanup and fixes for class checks when SuccUBus sucking
Diffstat (limited to 'engines/titanic/room_flags.h')
-rw-r--r--engines/titanic/room_flags.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/engines/titanic/room_flags.h b/engines/titanic/room_flags.h
index 8e86bf707e..e2fb91015a 100644
--- a/engines/titanic/room_flags.h
+++ b/engines/titanic/room_flags.h
@@ -209,9 +209,9 @@ public:
void setRandomLocation(PassengerClass classNum, bool flag);
/**
* Gets the succubus number associated with a given room
*/
- uint getSuccUBusNum(const CString &roomName) const;
+ PassengerClass getSuccUBusClass(const CString &roomName) const;
/**
* Gets the succubus room name associated with the current room flags
@@ -209,9 +209,9 @@ public:
void setRandomLocation(PassengerClass classNum, bool flag);
/**
- * Gets the succubus number associated with a given room
+ * Gets the passenger class for a succubus associated with a given room
*/